@@ -1,7 +1,9 @@
 import numpy as np
 
+from ase.calculators.calculator import Calculator, all_properties
 
-class SinglePointCalculator:
+
+class SinglePointCalculator(Calculator):
     """Special calculator for a single configuration.
 
     Used to remember the energy, force and stress for a given
@@ -9,69 +11,40 @@ class SinglePointCalculator:
     boundary conditions are changed, then asking for
     energy/forces/stress will raise an exception."""
     
-    def __init__(self, energy, forces, stress, magmoms, atoms):
-        """Save energy, forces and stresses for the current configuration."""
-        self.energy = energy
-        if forces is not None:
-            forces = np.array(forces, float)
-        self.forces = forces
-        if stress is not None:
-            stress = np.array(stress, float)
-        self.stress = stress
-        if magmoms is not None:
-            magmoms = np.array(magmoms, float)
-        self.magmoms = magmoms
+    def __init__(self, *args, **results):
+        """Save energy, forces, stress, ... for the current configuration."""
+        if args and isinstance(args[0], float):
+            # Old interface:
+            assert not results
+            for key, value in zip(['energy', 'forces', 'stress', 'magmoms'],
+                                  args):
+                if value is not None:
+                    results[key] = value
+            atoms = args[-1]
+        else:
+            if args:
+                atoms = args[0]
+            else:
+                atoms = results.pop('atoms')
+            
+        Calculator.__init__(self)
+        self.results = {}
+        for property, value in results.items():
+            assert property in all_properties
+            if value is None:
+                continue
+            if property in ['energy', 'magmom']:
+                self.results[property] = value
+            else:
+                self.results[property] = np.array(value, float)
         self.atoms = atoms.copy()
 
-    def calculation_required(self, atoms, quantities):
-        ok = self.atoms == atoms
-        return ('forces' in quantities and (self.forces is None or not ok) or
-                'energy' in quantities and (self.energy is None or not ok) or
-                'stress' in quantities and (self.stress is None or not ok) or
-                'magmoms' in quantities and (self.magmoms is None or not ok))
-
-    def update(self, atoms):
-        if self.atoms != atoms:
-            raise RuntimeError('Energy, forces and stress no longer correct.')
-
-    def get_potential_energy(self, atoms=None):
-        if atoms is not None:
-            self.update(atoms)
-        if self.energy is None:
-            raise RuntimeError('No energy.')
-        return self.energy
-
-    def get_forces(self, atoms):
-        self.update(atoms)
-        if self.forces is None:
-            raise RuntimeError('No forces.')
-        return self.forces
-
-    def get_stress(self, atoms):
-        self.update(atoms)
-        if self.stress is None:
+    def get_property(self, name, atoms):
+        if name not in self.results or self.check_state(atoms):
             raise NotImplementedError
-        return self.stress
-
-    def get_spin_polarized(self):
-        return self.magmoms is not None and self.magmoms.any()
-
-    def get_magnetic_moments(self, atoms=None):
-        if atoms is not None:
-            self.update(atoms)
-        if self.magmoms is not None:
-            return self.magmoms
-        else:
-            return np.zeros(len(self.positions))
-
-    def get_dipole_moment(self):
-        if hasattr(self, 'dipole'):
-            return self.dipole
-        return None
-
-    def set_dipole_moment(self, dipole):
-        self.dipole = dipole
+        return self.results[name]
 
+    
 class SinglePointKPoint:
     def __init__(self, weight, s, k, eps_n=[], f_n=[]):
         self.weight = weight
@@ -80,13 +53,35 @@ class SinglePointKPoint:
         self.eps_n = eps_n
         self.f_n = f_n
 
+
 class SinglePointDFTCalculator(SinglePointCalculator):
-    def __init__(self, energy, forces, stress, magmoms, atoms,
-                 eFermi=None):
-        SinglePointCalculator.__init__(self, energy, forces, stress, 
-                                       magmoms, atoms)
+    def __init__(self, *args, **results):
+        if args and isinstance(args[0], float):
+            # Old interface:
+            assert not results
+            for key, value in zip(['energy', 'forces', 'stress', 'magmoms'],
+                                  args):
+                if value is not None:
+                    results[key] = value
+            atoms = args[4]
+            if len(args) > 5:
+                eFermi = args[5]
+                if len(args) > 6:
+                    energies = args[6]
+        else:
+            if args:
+                atoms = args[0]
+            else:
+                atoms = results.pop('atoms')
+            eFermi = results.pop('eFermi', None)
+            energies = results.pop('energies', None)
+
+        SinglePointCalculator.__init__(self, atoms, **results)
+
         if eFermi is not None:
             self.eFermi = eFermi
+        if energies is not None:
+            self.energies = energies
         self.kpts = None
 
     def get_fermi_level(self):
