@@ -777,7 +777,7 @@ class EAM_Window(gtk.Window):
 
         # Now, set the parameters
         if param:
-            self.eam_file = param['fileobj']
+            self.eam_file = param['potential']
 
         self.show()
         self.grab_add()  # Lock all other windows
@@ -803,7 +803,7 @@ class EAM_Window(gtk.Window):
         if openr == gtk.RESPONSE_OK:
             param = {}
             filename = chooser.get_filename()
-            param['fileobj'] = filename
+            param['potential'] = filename
             setattr(self.owner, self.attrname, param)
 
         chooser.destroy()
