@@ -16,7 +16,7 @@ run_test(get_atoms, get_calculator, 'Hydrogen')
 import time
 
 import matplotlib
-matplotlib.rcParams['backend']="Agg"
+#matplotlib.rcParams['backend']="Agg"
 
 from ase.optimize.bfgs import BFGS
 from ase.optimize.lbfgs import LBFGS, LBFGSLineSearch
