@@ -4,7 +4,8 @@ from ase.calculators.calculator import get_calculator
 
 
 required = {'abinit': dict(ecut=200, toldfe=0.0001),
-            'aims': dict(sc_accuracy_eev=5.e-3)}
+            'aims': dict(sc_accuracy_eev=5.e-3),
+            'gpaw': dict(mode='lcao', basis='sz(dzp)', realspace=False)}
 
 
 def h2dft(name):
@@ -33,7 +34,7 @@ def h2dft(name):
     print(2 * e1pbe - e2pbe)
     print e1,e2,e1pbe,e2pbe
     calc = Calculator(name)
-    print calc.parameters, calc.results, calc.state
+    print calc.parameters, calc.results, calc.atoms
     assert not calc.calculation_required(h1, ['energy'])
     h1 = calc.get_atoms()
     print h1.get_potential_energy()
