@@ -6,8 +6,8 @@ msg += "Please verify your installation by running on the command line:\n"
 msg += "python -c 'import matplotlib'\n"
 msg += "\n"
 msg += "This module is optional and required in order to use "
-msg += "ASE's simple GUI (ag).\n"
-msg += "If you don't wish to use ag ignore this error, otherwise\n"
+msg += "ASE's simple GUI (ase-gui).\n"
+msg += "If you don't wish to use ase-gui ignore this error, otherwise\n"
 msg += "please install the package using "
 msg += "your distribution package manager, i.e.:\n"
 msg += "\n"
