@@ -17,6 +17,13 @@ atoms *= (1, 1, 2)
 images = [atoms.copy(), atoms.copy()]
 r = ['xyz', 'traj', 'cube', 'pdb', 'cfg', 'struct', 'cif', 'gen']
 
+try:
+    import json
+except ImportError:
+    pass
+else:
+    r += ['json', 'db']
+
 try:
     import Scientific
     version = Scientific.__version__.split('.')
@@ -37,12 +44,15 @@ except ImportError:
 else:
     w += ['png', 'eps']
 
+only_one_image = ['cube', 'png', 'eps', 'cfg', 'struct', 'etsf', 'gen',
+                  'json', 'db']
+
 for format in w:
     print format, 'O',
     fname1 = 'io-test.1.' + format
     fname2 = 'io-test.2.' + format
     write(fname1, atoms, format=format)
-    if format not in ['cube', 'png', 'eps', 'cfg', 'struct', 'etsf', 'gen']:
+    if format not in only_one_image:
         write(fname2, images, format=format)
 
     if format in r:
@@ -55,8 +65,7 @@ for format in w:
         if format in ['cfg']:
             assert np.all(np.abs(a1.get_array('extra') -
                                  atoms.get_array('extra')) < 1e-6)
-        if format not in ['cube', 'png', 'eps', 'cfg', 'struct', 'etsf',
-                          'gen']:
+        if format not in only_one_image:
             a2 = read(fname2)
             a3 = read(fname2, index=0)
             a4 = read(fname2, index=slice(None))
