@@ -103,80 +103,80 @@ class FullEquationOfState(EquationOfState):
 
 class DeltaCodesDFTCollection:
 
-    # http://molmod.ugent.be/sites/default/files/Delta_v1-1.zip
+    # http://molmod.ugent.be/sites/default/files/Delta_v2-0.zip
     wienref = """
     formula,V0,B0,B1
-    H,17.55,10.3,2.76
-    He,17.78,0.8,6.53
-    Li,20.22,13.9,3.75
-    Be,7.91,123.5,3.33
-    B,7.25,237.4,3.47
-    C,11.66,210.0,3.57
-    N,29.07,53.6,3.71
-    O,18.86,56.4,4.63
-    F,19.33,35.4,4.56
-    Ne,24.35,1.2,8.66
-    Na,37.09,7.7,3.74
-    Mg,22.93,35.7,4.26
-    Al,16.50,77.5,4.67
-    Si,20.55,88.8,4.33
-    P,21.61,68.8,4.42
-    S,17.35,85.5,4.44
-    Cl,39.18,19.3,4.49
-    Ar,52.21,0.7,7.84
-    K,73.71,3.6,3.73
-    Ca,42.21,17.3,3.17
-    Sc,24.62,54.6,3.40
-    Ti,17.41,112.7,3.59
-    V,13.52,185.2,3.73
-    Cr,11.91,183.8,7.37
-    Mn,11.61,131.2,0.85
-    Fe,11.45,196.1,6.14
-    Co,10.94,215.4,5.11
-    Ni,10.98,204.1,4.96
-    Cu,12.01,142.3,5.17
-    Zn,15.26,74.9,5.71
-    Ga,20.38,49.1,5.33
-    Ge,24.09,59.5,5.08
-    As,22.57,69.7,4.29
-    Se,29.97,47.9,4.65
-    Br,39.78,22.6,5.15
-    Kr,65.36,0.8,18.24
-    Rb,91.13,2.8,2.32
-    Sr,54.56,11.3,4.17
-    Y,32.86,41.3,2.95
-    Zr,23.40,94.1,3.25
-    Nb,18.16,168.7,3.50
-    Mo,15.83,260.4,4.26
-    Tc,14.47,301.4,4.56
-    Ru,13.81,315.4,4.96
-    Rh,14.08,260.6,5.44
-    Pd,15.32,170.0,5.73
-    Ag,17.85,91.5,5.57
-    Cd,22.86,44.1,7.40
-    In,27.50,34.8,4.87
-    Sn,36.87,36.1,4.91
-    Sb,31.82,50.5,4.53
-    Te,34.94,44.6,4.53
-    I,50.35,18.7,5.01
-    Xe,87.20,0.6,3.42
-    Cs,117.75,2.0,3.59
-    Ba,63.21,8.8,1.34
-    Lu,29.06,47.0,3.49
-    Hf,22.54,107.5,3.43
-    Ta,18.30,189.5,3.67
-    W,16.17,303.5,4.37
-    Re,14.98,365.0,4.48
-    Os,14.31,401.3,5.33
-    Ir,14.56,345.3,3.64
-    Pt,15.67,250.2,5.57
-    Au,17.99,138.8,5.82
-    Hg,29.51,8.3,9.83
-    Tl,31.41,27.0,6.26
-    Pb,32.03,39.4,3.96
-    Bi,36.93,42.7,4.34
-    Po,37.57,45.4,5.13
-    Rn,88.95,0.8,0.69
+    H,17.387,10.315,3.025
+    He,17.778,0.847,6.534
+    Li,20.216,13.879,3.754
+    Be,7.915,123.039,3.154
+    B,7.245,237.599,3.476
+    C,11.654,209.648,3.565
+    N,28.896,54.288,3.753
+    O,18.564,51.231,3.927
+    F,19.347,35.015,4.246
+    Ne,24.349,1.242,8.664
+    Na,37.089,7.728,3.736
+    Mg,22.934,35.748,4.263
+    Al,16.503,77.512,4.667
+    Si,20.553,88.673,4.227
+    P,21.614,68.863,4.416
+    S,17.346,85.495,4.440
+    Cl,39.175,19.324,4.489
+    Ar,52.209,0.704,7.838
+    K,73.710,3.586,3.734
+    Ca,42.208,17.300,3.167
+    Sc,24.621,54.559,3.402
+    Ti,17.407,112.712,3.591
+    V,13.517,185.231,3.731
+    Cr,11.910,183.841,7.374
+    Mn,11.611,131.159,0.852
+    Fe,11.451,196.127,6.137
+    Co,10.948,216.191,5.076
+    Ni,10.986,204.685,4.852
+    Cu,12.017,143.702,5.198
+    Zn,15.270,75.617,5.377
+    Ga,20.377,49.087,5.330
+    Ge,24.094,59.486,5.084
+    As,22.571,69.732,4.294
+    Se,29.973,47.637,4.548
+    Br,39.780,22.629,5.154
+    Kr,65.226,0.851,22.009
+    Rb,91.130,2.842,2.321
+    Sr,54.561,11.333,4.172
+    Y,32.864,41.320,2.952
+    Zr,23.402,94.061,3.247
+    Nb,18.155,168.691,3.504
+    Mo,15.825,260.410,4.264
+    Tc,14.472,301.391,4.555
+    Ru,13.810,315.359,4.955
+    Rh,14.082,260.576,5.440
+    Pd,15.326,170.442,5.854
+    Ag,17.855,91.328,5.799
+    Cd,22.866,44.247,7.089
+    In,27.497,34.759,4.870
+    Sn,36.883,36.020,5.038
+    Sb,31.786,50.718,4.495
+    Te,35.009,44.806,4.703
+    I,50.339,18.699,5.222
+    Xe,87.318,0.569,-0.724
+    Cs,117.748,1.964,3.592
+    Ba,63.200,8.431,3.299
+    Lu,29.060,47.725,4.048
+    Hf,22.551,108.082,3.225
+    Ta,18.296,193.730,4.774
+    W,16.175,302.590,4.300
+    Re,14.987,364.610,4.466
+    Os,14.320,402.199,4.352
+    Ir,14.533,341.743,6.958
+    Pt,15.678,251.750,5.342
+    Au,17.993,139.863,5.985
+    Hg,29.716,8.155,8.077
+    Tl,31.456,26.683,4.565
+    Pb,32.000,39.551,5.954
+    Bi,36.939,42.556,4.626
+    Po,37.570,45.523,5.018
+    Rn,92.765,0.544,13.133
     """
 
     # http://molmod.ugent.be/sites/default/files/Delta_v1-1.zip
@@ -880,7 +880,7 @@ class DeltaCodesDFTTask(BulkTask):
 
 if __name__ == '__main__':
     # download and create the project databases
-    src = 'http://molmod.ugent.be/sites/default/files/Delta_v1-1.zip'
+    src = 'http://molmod.ugent.be/sites/default/files/Delta_v2-0.zip'
     name = os.path.basename(src)
     dir = 'Delta'
     if not os.path.exists(dir): os.makedirs(dir)
