@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 """Modules for calculating thermochemical information from computational
 outputs."""
 
@@ -65,7 +64,7 @@ class ThermoChem:
         kT = units.kB * temperature
         dU = 0.
         for energy in self.vib_energies:
-            dU += energy / (np.exp(energy/kT) - 1.)
+            dU += energy / (np.exp(energy / kT) - 1.)
         return dU
 
     def _vibrational_entropy_contribution(self, temperature):
@@ -76,7 +75,7 @@ class ThermoChem:
         S_v = 0.
         for energy in self.vib_energies:
             x = energy / kT
-            S_v += x / (np.exp(x)-1.) - np.log(1-np.exp(-x))
+            S_v += x / (np.exp(x) - 1.) - np.log(1. - np.exp(-x))
         S_v *= units.kB
         return S_v
 
@@ -90,7 +89,7 @@ class HarmonicThermo(ThermoChem):
     """Class for calculating thermodynamic properties in the approximation
     that all degrees of freedom are treated harmonically. Often used for
     adsorbates.
-    
+
     Inputs:
 
     vib_energies : list
@@ -102,8 +101,8 @@ class HarmonicThermo(ThermoChem):
         number of energies. Units of energies are eV.
     electronicenergy : float
         the electronic energy in eV
-        (If the electronicenergy is unspecified, then the methods of this
-        class can be interpreted as the energy corrections.)
+        (if electronicenergy is unspecified, then the methods of this
+        class can be interpreted as the energy corrections)
     """
 
     def __init__(self, vib_energies, electronicenergy=None):
@@ -112,7 +111,7 @@ class HarmonicThermo(ThermoChem):
         if sum(np.iscomplex(self.vib_energies)):
             raise ValueError('Imaginary vibrational energies are present.')
         else:
-            self.vib_energies = np.real(self.vib_energies)  # clear +0.j 
+            self.vib_energies = np.real(self.vib_energies)  # clear +0.j
 
         if electronicenergy:
             self.electronicenergy = electronicenergy
@@ -127,7 +126,7 @@ class HarmonicThermo(ThermoChem):
         write = self._vprint
         fmt = '%-15s%13.3f eV'
         write('Internal energy components at T = %.2f K:' % temperature)
-        write('='*31)
+        write('=' * 31)
 
         U = 0.
 
@@ -142,9 +141,9 @@ class HarmonicThermo(ThermoChem):
         write(fmt % ('Cv_harm (0->T)', dU_v))
         U += dU_v
 
-        write('-'*31)
+        write('-' * 31)
         write(fmt % ('U', U))
-        write('='*31)
+        write('=' * 31)
         return U
 
     def get_entropy(self, temperature, verbose=True):
@@ -155,23 +154,23 @@ class HarmonicThermo(ThermoChem):
         write = self._vprint
         fmt = '%-15s%13.7f eV/K%13.3f eV'
         write('Entropy components at T = %.2f K:' % temperature)
-        write('='*49)
-        write('%15s%13s     %13s'%('', 'S', 'T*S'))
+        write('=' * 49)
+        write('%15s%13s     %13s' % ('', 'S', 'T*S'))
 
         S = 0.
 
         S_v = self._vibrational_entropy_contribution(temperature)
-        write(fmt%('S_harm', S_v, S_v*temperature))
+        write(fmt % ('S_harm', S_v, S_v * temperature))
         S += S_v
 
-        write('-'*49)
-        write(fmt%('S', S, S*temperature))
-        write('='*49)
+        write('-' * 49)
+        write(fmt % ('S', S, S * temperature))
+        write('=' * 49)
         return S
 
-    def get_free_energy(self, temperature, verbose=True):
-        """Returns the free energy, in eV, in the harmonic approximation
-        at a specified temperature (K)."""
+    def get_gibbs_energy(self, temperature, verbose=True):
+        """Returns the Gibbs free energy, in eV, in the harmonic
+        approximation at a specified temperature (K)."""
 
         self.verbose = True
         write = self._vprint
@@ -183,13 +182,22 @@ class HarmonicThermo(ThermoChem):
 
         write('')
         write('Free energy components at T = %.2f K:' % temperature)
-        write('='*23)
+        write('=' * 23)
         fmt = '%5s%15.3f eV'
         write(fmt % ('U', U))
         write(fmt % ('-T*S', -temperature * S))
-        write('-'*23)
+        write('-' * 23)
         write(fmt % ('G', G))
-        write('='*23)
+        write('=' * 23)
+        return G
+
+    def get_free_energy(self, temperature, verbose=True):
+        """Deprecated: use 'get_gibbs_energy' instead."""
+        import warnings
+        warnings.warn('get_free_energy is deprecated. Please use '
+                      'get_gibbs_energy instead.',
+                      DeprecationWarning, stacklevel=2)
+        G = self.get_gibbs_energy(temperature, verbose)
         return G
 
 
@@ -204,16 +212,16 @@ class IdealGasThermo(ThermoChem):
         a list of the vibrational energies of the molecule (e.g., from
         ase.vibrations.Vibrations.get_energies). The number of vibrations
         used is automatically calculated by the geometry and the number of
-        atoms. If more are specified than are needed, then the lowest 
-        numbered vibrations are neglected. If either atoms or natoms is 
+        atoms. If more are specified than are needed, then the lowest
+        numbered vibrations are neglected. If either atoms or natoms is
         unspecified, then uses the entire list. Units are eV.
     geometry : 'monatomic', 'linear', or 'nonlinear'
         geometry of the molecule
     electronicenergy : float
         the electronic energy in eV
-        (If electronicenergy is unspecified, then the methods of this
+        (if electronicenergy is unspecified, then the methods of this
         class can be interpreted as the enthalpy and free energy
-        corrections.)
+        corrections)
     natoms : integer
         the number of atoms, used along with 'geometry' to determine how
         many vibrations to use. (Not needed if an atoms object is supplied
@@ -250,9 +258,9 @@ class IdealGasThermo(ThermoChem):
         # Cut the vibrations to those needed from the geometry.
         if natoms:
             if geometry == 'nonlinear':
-                self.vib_energies = vib_energies[-(3*natoms-6):]
+                self.vib_energies = vib_energies[-(3 * natoms - 6):]
             elif geometry == 'linear':
-                self.vib_energies = vib_energies[-(3*natoms-5):]
+                self.vib_energies = vib_energies[-(3 * natoms - 5):]
             elif geometry == 'monatomic':
                 self.vib_energies = []
         else:
@@ -261,8 +269,8 @@ class IdealGasThermo(ThermoChem):
         if sum(np.iscomplex(self.vib_energies)):
             raise ValueError('Imaginary frequencies are present.')
         else:
-            self.vib_energies = np.real(self.vib_energies) # clear +0.j 
-        self.referencepressure = 101325. # Pa
+            self.vib_energies = np.real(self.vib_energies)  # clear +0.j
+        self.referencepressure = 101325.  # Pa
 
     def get_enthalpy(self, temperature, verbose=True):
         """Returns the enthalpy, in eV, in the ideal gas approximation
@@ -272,7 +280,7 @@ class IdealGasThermo(ThermoChem):
         write = self._vprint
         fmt = '%-15s%13.3f eV'
         write('Enthalpy components at T = %.2f K:' % temperature)
-        write('='*31)
+        write('=' * 31)
 
         H = 0.
 
@@ -283,18 +291,18 @@ class IdealGasThermo(ThermoChem):
         write(fmt % ('E_ZPE', zpe))
         H += zpe
 
-        Cv_t = 3./2. * units.kB # translational heat capacity (3-d gas)
+        Cv_t = 3. / 2. * units.kB  # translational heat capacity (3-d gas)
         write(fmt % ('Cv_trans (0->T)', Cv_t * temperature))
         H += Cv_t * temperature
 
-        if self.geometry == 'nonlinear': # rotational heat capacity
-            Cv_r = 3./2.*units.kB
+        if self.geometry == 'nonlinear':  # rotational heat capacity
+            Cv_r = 3. / 2. * units.kB
         elif self.geometry == 'linear':
             Cv_r = units.kB
         elif self.geometry == 'monatomic':
             Cv_r = 0.
         write(fmt % ('Cv_rot (0->T)', Cv_r * temperature))
-        H += Cv_r*temperature
+        H += Cv_r * temperature
 
         dH_v = self._vibrational_energy_contribution(temperature)
         write(fmt % ('Cv_vib (0->T)', dH_v))
@@ -304,9 +312,9 @@ class IdealGasThermo(ThermoChem):
         write(fmt % ('(C_v -> C_p)', Cp_corr))
         H += Cp_corr
 
-        write('-'*31)
+        write('-' * 31)
         write(fmt % ('H', H))
-        write('='*31)
+        write('=' * 31)
         return H
 
     def get_entropy(self, temperature, pressure, verbose=True):
@@ -331,7 +339,7 @@ class IdealGasThermo(ThermoChem):
         mass = sum(self.atoms.get_masses()) * units._amu  # kg/molecule
         S_t = (2 * np.pi * mass * units._k *
                temperature / units._hplanck**2)**(3.0 / 2)
-        S_t *= units._k * temperature / self.referencepressure 
+        S_t *= units._k * temperature / self.referencepressure
         S_t = units.kB * (np.log(S_t) + 5.0 / 2.0)
         write(fmt % ('S_trans (1 atm)', S_t, S_t * temperature))
         S += S_t
@@ -376,9 +384,9 @@ class IdealGasThermo(ThermoChem):
         write('=' * 49)
         return S
 
-    def get_free_energy(self, temperature, pressure, verbose=True):
-        """Returns the free energy, in eV, in the ideal gas approximation
-        at a specified temperature (K) and pressure (Pa)."""
+    def get_gibbs_energy(self, temperature, pressure, verbose=True):
+        """Returns the Gibbs free energy, in eV, in the ideal gas
+        approximation at a specified temperature (K) and pressure (Pa)."""
 
         self.verbose = verbose
         write = self._vprint
@@ -399,3 +407,174 @@ class IdealGasThermo(ThermoChem):
         write(fmt % ('G', G))
         write('=' * 23)
         return G
+
+    def get_free_energy(self, temperature, pressure, verbose=True):
+        """Deprecated: use 'get_gibbs_energy' instead."""
+        import warnings
+        warnings.warn('get_free_energy is deprecated. Please use '
+                      'get_gibbs_energy instead.',
+                      DeprecationWarning, stacklevel=2)
+        G = self.get_gibbs_energy(temperature, pressure, verbose)
+        return G
+
+
+class CrystalThermo(ThermoChem):
+    """Class for calculating thermodynamic properties of a crystalline
+    solid in the approximation that a lattice of N atoms behaves as a
+    system of 3N independent harmonic oscillators.
+
+    Inputs:
+
+    phonon_DOS : list
+        a list of the phonon density of states,
+        where each value represents the phonon DOS at the vibrational energy
+        value of the corresponding index in phonon_energies.
+
+    phonon_energies : list
+        a list of the range of vibrational energies (hbar*omega) over which
+        the phonon density of states has been evaluated. This list should be
+        the same length as phonon_DOS and integrating phonon_DOS over
+        phonon_energies should yield approximately 3N, where N is the number
+        of atoms per unit cell. If the first element of this list is
+        zero-valued it will be deleted along with the first element of
+        phonon_DOS. Units of vibrational energies are eV.
+
+    electronicenergy : float
+        the electronic energy in eV
+        (if electronicenergy is unspecified, then the methods of this
+        class can be interpreted as the phonon energy corrections.)
+
+    formula_units : int
+        the number of formula units per unit cell. If unspecified, the
+        thermodynamic quantities calculated will be listed on a
+        per-unit-cell basis.
+    """
+
+    def __init__(self, phonon_DOS, phonon_energies,
+                 formula_units=None, electronicenergy=None):
+        self.phonon_energies = phonon_energies
+        self.phonon_DOS = phonon_DOS
+
+        if formula_units:
+            self.formula_units = formula_units
+            if electronicenergy:
+                self.electronicenergy = electronicenergy / formula_units
+            else:
+                self. electronicenergy = electronicenergy
+        else:
+            self.formula_units = 0
+            if electronicenergy:
+                self.electronicenergy = electronicenergy
+            else:
+                self.electronicenergy = 0
+
+    def get_internal_energy(self, temperature, verbose=True):
+        """Returns the internal energy, in eV, of crystalline solid
+        at a specified temperature (K)."""
+
+        self.verbose = verbose
+        write = self._vprint
+        fmt = '%-15s%13.4f eV'
+        if self.formula_units == 0:
+            write('Internal energy components at '
+                  'T = %.2f K,\non a per-unit-cell basis:' % temperature)
+        else:
+            write('Internal energy components at '
+                  'T = %.2f K,\non a per-formula-unit basis:' % temperature)
+        write('=' * 31)
+
+        U = 0.
+
+        omega_e = self.phonon_energies
+        dos_e = self.phonon_DOS
+        if omega_e[0] == 0.:
+            omega_e = np.delete(omega_e, 0)
+            dos_e = np.delete(dos_e, 0)
+
+        write(fmt % ('E_elec', self.electronicenergy))
+        U += self.electronicenergy
+
+        zpe_list = omega_e / 2.
+        if self.formula_units == 0:
+            zpe = np.trapz(zpe_list * dos_e, omega_e)
+        else:
+            zpe = np.trapz(zpe_list * dos_e, omega_e) / self.formula_units
+        write(fmt % ('E_ZPE', zpe))
+        U += zpe
+
+        B = 1. / (units.kB * temperature)
+        E_vib = omega_e / (np.exp(omega_e * B) - 1.)
+        if self.formula_units == 0:
+            E_phonon = np.trapz(E_vib * dos_e, omega_e)
+        else:
+            E_phonon = np.trapz(E_vib * dos_e, omega_e) / self.formula_units
+        write(fmt % ('E_phonon', E_phonon))
+        U += E_phonon
+
+        write('-' * 31)
+        write(fmt % ('U', U))
+        write('=' * 31)
+        return U
+
+    def get_entropy(self, temperature, verbose=True):
+        """Returns the entropy, in eV/K, of crystalline solid
+        at a specified temperature (K)."""
+
+        self.verbose = verbose
+        write = self._vprint
+        fmt = '%-15s%13.7f eV/K%13.4f eV'
+        if self.formula_units == 0:
+            write('Entropy components at '
+                  'T = %.2f K,\non a per-unit-cell basis:' % temperature)
+        else:
+            write('Entropy components at '
+                  'T = %.2f K,\non a per-formula-unit basis:' % temperature)
+        write('=' * 49)
+        write('%15s%13s     %13s' % ('', 'S', 'T*S'))
+
+        omega_e = self.phonon_energies
+        dos_e = self.phonon_DOS
+        if omega_e[0] == 0.:
+            omega_e = np.delete(omega_e, 0)
+            dos_e = np.delete(dos_e, 0)
+
+        B = 1. / (units.kB * temperature)
+        S_vib = (omega_e / (temperature * (np.exp(omega_e * B) - 1.))
+                 - units.kB * np.log(1. - np.exp(-omega_e * B)))
+        if self.formula_units == 0:
+            S = np.trapz(S_vib * dos_e, omega_e)
+        else:
+            S = np.trapz(S_vib * dos_e, omega_e) / self.formula_units
+
+        write('-' * 49)
+        write(fmt % ('S', S, S * temperature))
+        write('=' * 49)
+        return S
+
+    def get_helmholtz_energy(self, temperature, verbose=True):
+        """Returns the Helmholtz free energy, in eV, of crystalline solid
+        at a specified temperature (K)."""
+
+        self.verbose = True
+        write = self._vprint
+
+        U = self.get_internal_energy(temperature, verbose=verbose)
+        write('')
+        S = self.get_entropy(temperature, verbose=verbose)
+        F = U - temperature * S
+
+        write('')
+        if self.formula_units == 0:
+            write('Helmholtz free energy components at '
+                  'T = %.2f K,\non a per-unit-cell basis:' % temperature)
+        else:
+            write('Helmholtz free energy components at '
+                  'T = %.2f K,\non a per-formula-unit basis:' % temperature)
+        write('=' * 23)
+        fmt = '%5s%15.4f eV'
+        write(fmt % ('U', U))
+        write(fmt % ('-T*S', -temperature * S))
+        write('-' * 23)
+        write(fmt % ('F', F))
+        write('=' * 23)
+        return F
