@@ -249,7 +249,8 @@ class IncompatibleCellError(ValueError):
 
 
 def stack(atoms1, atoms2, axis=2, cell=None, fix=0.5,  
-          maxstrain=0.5, distance=None, reorder=False):
+          maxstrain=0.5, distance=None, reorder=False,
+          output_strained=False):
     """Return a new Atoms instance with *atoms2* stacked on top of
     *atoms1* along the given axis. Periodicity in all directions is
     ensured.
@@ -279,6 +280,10 @@ def stack(atoms1, atoms2, axis=2, cell=None, fix=0.5,
     all atoms with the same symbol will follow sequensially after each
     other, eg: 'Al2MnAl10Fe' -> 'Al12FeMn'.    
 
+    If *output_strained* is True, then the strained versions of
+    *atoms1* and *atoms2* are returned in addition to the stacked
+    structure.
+
     Example:
 
     >>> import ase
@@ -339,6 +344,9 @@ def stack(atoms1, atoms2, axis=2, cell=None, fix=0.5,
 
     atoms1.set_cell(cell1, scale_atoms=True)
     atoms2.set_cell(cell2, scale_atoms=True)
+    if output_strained:
+        atoms1_strained = atoms1.copy()
+        atoms2_strained = atoms2.copy()
 
     if distance is not None:
         from scipy.optimize import fmin
@@ -372,7 +380,10 @@ def stack(atoms1, atoms2, axis=2, cell=None, fix=0.5,
     if reorder:
         atoms1 = sort(atoms1)
 
-    return atoms1
+    if output_strained:
+        return atoms1, atoms1_strained, atoms2_strained
+    else:
+        return atoms1
 
 
 def sort(atoms, tags=None):
@@ -457,6 +468,49 @@ def rotate(atoms, a1, a2, b1, b2, rotate_cell=True, center=(0, 0, 0)):
     if rotate_cell:
         atoms.cell[:] = np.dot(atoms.cell, R.T)
 
+
+
+
+def minimize_tilt_ij(atoms, modified=1, fixed=0, fold_atoms=True):
+    """Minimize the tilt angle for two given axes.
+
+    The problem is underdetermined. Therefore one can choose one axis 
+    that is kept fixed.
+    """
+    
+    orgcell_cc = atoms.get_cell()
+    pbc_c = atoms.get_pbc()
+    i = fixed
+    j = modified
+    if not (pbc_c[i] and pbc_c[j]):
+        raise RuntimeError('Axes have to be periodic')
+
+    prod_cc = np.dot(orgcell_cc, orgcell_cc.T)
+    cell_cc = 1. * orgcell_cc
+    nji = np.floor(- prod_cc[i, j] / prod_cc[i, i] + 0.5)
+    cell_cc[j] = orgcell_cc[j] + nji * cell_cc[i]
+
+    # sanity check
+    def volume(cell):
+        return np.abs(np.dot(cell[2], np.cross(cell[0], cell[1])))
+    V = volume(cell_cc)
+    assert(abs(volume(orgcell_cc) - V) / V < 1.e-10)
+
+    atoms.set_cell(cell_cc)
+
+    if fold_atoms:
+        atoms.set_scaled_positions(atoms.get_scaled_positions())
+
+def minimize_tilt(atoms, order=range(3), fold_atoms=True):
+    """Minimize the tilt angles of the unit cell."""
+    pbc_c = atoms.get_pbc()
+    
+    for i1, c1 in enumerate(order):
+        for c2 in order[i1 + 1:]:
+            if pbc_c[c1] and pbc_c[c2]:
+                minimize_tilt_ij(atoms, c1, c2, fold_atoms)
+
+
 #-----------------------------------------------------------------
 # Self test
 if __name__ == '__main__':
