@@ -1,5 +1,5 @@
 # creates:  Ag-eos.png
 execfile('eos1.py')
 import matplotlib
-matplotlib.use('Agg')
+#matplotlib.use('Agg')
 execfile('eos2.py')
